************************************
*
*** ATTRITION ANALYSIS *************
*
************************************
set more off

***************************************************
*** 1. PID OR PRE-ITEM PREDICT MISSING ON POST? (REPORTED IN FOOTNOTE 4)
***************************************************

reg BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy talkpol likely_2012 trust_int trust_gov app_obama app_congress r_black r_hispanic r_otherrace gender age age2 income incomemis educ pid7 interest 
keep if e(sample)

foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local label : variable label `i'
gen miss_`i'=(`i'_post==.)
label var miss_`i' "`label' Missing"
gen pidX`i'=`i'*pid7
label var pidX`i' "PID X Pre-Election"
label var `i' "Pre-Election"
reg miss_`i' pidX`i' pid7 `i', r
local f=Ftail(e(df_m),e(df_r),e(F))
if "`i'"=="BF_conscientiousness"{
outreg using "logs/footnote4.out", se bracket rdec(3) adec(3) 3aster addstat("Prob > F",`f') replace
}
else{
outreg using "logs/footnote4.out", se bracket rdec(3) adec(3) 3aster addstat("Prob > F",`f') append 
}
reg miss_`i' pid7 `i', r
outreg using "logs/footnote4.out", se bracket rdec(3) adec(3) 3aster addstat("Prob > F",`f') append 
}

reg miss_app_obama pidXapp_obama pid7 app_obama,
reg miss_app_congress pidXapp_congress pid7 app_congress, r

*************************
*** 2. BOUNDS (REPORTED IN FOOTNOTES 5 & 10)
*************************

**************************************************
*** FILL IN MISSING VALUES WITH BIGGEST CHANGE (REPORTED IN FOOTNOTE 5)
**************************************************
foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen nomiss_`i'=`i'_post
sum `i' 
replace nomiss_`i'=r(min) if abs(r(min)-`i')>=abs(r(max)-`i') & nomiss_`i'==.
replace nomiss_`i'=r(max) if abs(r(max)-`i')>abs(r(min)-`i') & nomiss_`i'==.
label var nomiss_`i' "Post No Missing"
}

foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen `i'_change2=nomiss_`i'-`i'
label var `i'_change2 "Change No Missing"
}

**************************
*** STANDARDIZE **********
**************************
foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy talkpol likely_2012 trust_int trust_gov app_obama app_congress{
local vname= subinstr("`i'", "BF_","",.)
sum `i'
local label : variable label `i'

local label=subinstr("`label'"," (0-1)","",.)
local label=subinstr("`label'","; 0-1","",.)
local label=subinstr("`label'"," (0=not at all happy; 3=very happy)","",.)
local label=subinstr("`label'"," (0-7)","",.)
local label=subinstr("`label'"," (0=Not at all likely; 100=Very likely)","",.)
local label=subinstr("`label'"," (0=You can't be too careful; 100=Most people can be trusted)","",.)
local label=subinstr("`label'"," (0=Never; 100=Always)","",.)
local label=subinstr("`label'"," (0=strongly disapprove; 3=strongly approve)","",.)

gen std_`vname'_abs_change=abs(`i'_change2)/r(sd)
label var std_`vname'_abs_change "Absolute Change in `label' (standardized) No Missing"
gen std_`vname'_change=`i'_change2/r(sd)
label var std_`vname'_change "Change in `label' No Missing"
gen std_`vname'=(`i'-r(mean))/r(sd)
label var std_`vname' "`label'"
gen std_`vname'_post=(nomiss_`i'-r(mean))/r(sd)
label var std_`vname'_post "`label' (Post-Election No Missing; standardized)"
}

*** DICHOTOMIZE MEASURES ***
foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local label : variable label std_`i'
gen dich_`i'=std_`i'>0
gen dich_`i'_post=std_`i'_post>0
gen dich_`i'_change=dich_`i'_post-dich_`i'
label var dich_`i' "`label' (dichotomous)"
label var dich_`i'_post "`label' (Post-Election; dichotomous)"
label var dich_`i'_change "Change in `label' (dichotomous)"
}

*********************************
** CORRELATIONS *****************
*********************************
corr std_conscientiousness std_openness std_agreeableness std_stability std_extraversion std_rwa std_nfc std_nte std_happy std_talkpol std_likely_2012 std_trust_int std_trust_gov std_app_obama std_app_congress

file open myfile using "logs/footnote5_table2.csv", write replace 
file write myfile ",,(1),(2)" _n
file write myfile "Variable,Scale Source,Polychoric Correlation,Tetrachoric Correlation (dichotomous),% identical" _n
local shifts="Statistically significant mean shifts: "
qui count
local N=r(N)
*counter to indicate shift in scale type
local counter=0
local scales="Two 7-point scales; Three 2-point scales; One 3-point/one 2-point scale; One 4-point/one 3-point scale; 4-point scale; 100-point slider; 4-point scale; 7-point scale; 100-point slider"

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local counter=`counter'+1
if (`counter'==1)|(`counter'==6)|(`counter'==7)|(`counter'==8)|(`counter'==9)|(`counter'==10)|(`counter'==12)|(`counter'==14)|(`counter'==15){
 gettoken scale scales : scales, parse(";") 
local scale_label="`scale'"
 gettoken scale scales : scales, parse(";") 
}
local label : variable label std_`i'
polychoric std_`i' std_`i'_post
local polychoric=r(rho)
tetrachoric dich_`i' dich_`i'_post
local dich_corr=r(rho)
count if std_`i'==std_`i'_post
local pct_move=r(N)/`N'
ttest std_`i'_change==0
if r(p)<.05{
 local p=round(r(p),.001)
 local val=round(r(mu_1),.001)
 local shifts="`shifts' `label' (`val', p=`p'); "
}
 file write myfile "`label',`scale_label',`polychoric',`dich_corr',`pct_move'" _n
}
 file write myfile "Values in column (1) are polychoric correlations between standardized pre- and post-election variables. Values in column (2) are tetrachoric correlations between dichotomized pre- and post-election variables. Values in column (3) are percentages of cases where respondents pre- and post-election wave measures were identical. `shifts'.,," _n
file close myfile


***************************************************
*** NOW, DEMS AND REPS AT RESPECTIVE MEANS (REPORTED IN FOOTNOTE 10)
***************************************************
drop nomiss_BF_conscientiousness-dich_likely_2012_change

foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen nomiss_`i'=`i'_post
sum `i' if pid_democrat==1
replace nomiss_`i'=r(mean) if nomiss_`i'==. & pid_democrat==1
sum `i' if pid_republican==1
replace nomiss_`i'=r(mean) if nomiss_`i'==. & pid_republican==1
sum `i' if pid_republican==0 & pid_democrat==0
replace nomiss_`i'=r(mean) if nomiss_`i'==. & pid_republican==0 & pid_democrat==0
label var nomiss_`i' "Post No Missing"
}

foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
gen `i'_change2=nomiss_`i'-`i'
label var `i'_change2 "Change No Missing"
}

**************************
*** STANDARDIZE **********
**************************
foreach i in BF_conscientiousness BF_openness BF_agreeableness BF_stability BF_extraversion rwa nfc nte happy talkpol likely_2012 trust_int trust_gov app_obama app_congress{
local vname= subinstr("`i'", "BF_","",.)
sum `i'
local label : variable label `i'

local label=subinstr("`label'"," (0-1)","",.)
local label=subinstr("`label'","; 0-1","",.)
local label=subinstr("`label'"," (0=not at all happy; 3=very happy)","",.)
local label=subinstr("`label'"," (0-7)","",.)
local label=subinstr("`label'"," (0=Not at all likely; 100=Very likely)","",.)
local label=subinstr("`label'"," (0=You can't be too careful; 100=Most people can be trusted)","",.)
local label=subinstr("`label'"," (0=Never; 100=Always)","",.)
local label=subinstr("`label'"," (0=strongly disapprove; 3=strongly approve)","",.)

gen std_`vname'_abs_change=abs(`i'_change2)/r(sd)
label var std_`vname'_abs_change "Absolute Change in `label' (standardized) No Missing"
gen std_`vname'_change=`i'_change2/r(sd)
label var std_`vname'_change "Change in `label' No Missing"
gen std_`vname'=(`i'-r(mean))/r(sd)
label var std_`vname' "`label'"
gen std_`vname'_post=(nomiss_`i'-r(mean))/r(sd)
label var std_`vname'_post "`label' (Post-Election No Missing; standardized)"
}

*** DICHOTOMIZE MEASURES ***
foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
local label : variable label std_`i'
gen dich_`i'=std_`i'>0
gen dich_`i'_post=std_`i'_post>0
gen dich_`i'_change=dich_`i'_post-dich_`i'
label var dich_`i' "`label' (dichotomous)"
label var dich_`i'_post "`label' (Post-Election; dichotomous)"
label var dich_`i'_change "Change in `label' (dichotomous)"
}

*************************
*** REGRESSIONS *********
*************************

foreach i in conscientiousness openness agreeableness stability extraversion rwa nfc nte happy trust_int trust_gov app_obama app_congress talkpol likely_2012{
reg std_`i'_change pid_democrat pid_republican, r
lincom pid_democrat-pid_republican 
local diff=r(estimate)
local diff_p=ttail(r(df),abs(r(estimate)/r(se)))*2
test pid_democrat pid_republican 
if "`i'"=="conscientiousness"{
outreg using "logs/footnote10_table3_col1&2.out", se bracket rdec(3) 3aster replace adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}
else{
outreg using "logs/footnote10_table3_col1&2.out", se bracket rdec(3) 3aster append adec(3) addstat("Joint Significance of PID",r(p),"Difference (Dem-Rep)",`diff',"Significance of Difference",`diff_p')
}
}
